@@ -14,6 +14,10 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
+#ifdef Q_WS_MAEMO_5
+#include <libosso.h>
+#endif
+
 #include <QFileDialog>
 #include <QMessageBox>
 #include <QDataStream>
@@ -55,23 +59,27 @@ MainWindow::MainWindow(QWidget *parent) :
   timerRefreshTimeMs = 100;
 
   connect(actionReset, SIGNAL(triggered()), this , SLOT(resetProgram()));
-  connect(actionResetFs, SIGNAL(triggered()), this , SLOT(resetProgramAndFullscreen()));
-//  connect(actionResetFs, SIGNAL(triggered()), this , SLOT(actionReset->Trigger));
-  connect(actionSimulated_click, SIGNAL(triggered()), this , SLOT(mainButtonRefresh()));
+  connect(actionSimulated_click, SIGNAL(triggered()), this , SLOT(mainButtonHandler()));
   connect(actionPause, SIGNAL(triggered()), this , SLOT(pauseCounting()));
+  connect(actionStartStopMode, SIGNAL(triggered()), this, SLOT(toggleStartStopMode()));
+
   connect(actionSave_full_list, SIGNAL(triggered()), this , SLOT(saveToFile()));
   connect(actionEnable_full_date, SIGNAL(triggered()), this , SLOT(toggleFullDate()));
   connect(actionEnable_time_and_date, SIGNAL(triggered()), this , SLOT(toggleTimeDate()));
-  connect(actionAbout, SIGNAL(triggered()), this , SLOT(about()));
   connect(actionShow_full_list, SIGNAL(triggered()), this , SLOT(showFullList()));
+
   connect(action_Fullscreen, SIGNAL(triggered()), this, SLOT(showFullScreenHandler()));
+  connect(actionResetFs, SIGNAL(triggered()), this , SLOT(resetProgramAndFullscreen()));
   connect(actionChangeNumberOfLines, SIGNAL(triggered()), this, SLOT(changeNumberOfLines()));
   connect(actionChangeFontSize, SIGNAL(triggered()), this, SLOT(changeFontSize()));
 
-  connect(this->mainButton, SIGNAL(clicked()), this, SLOT(mainButtonRefresh()));
+  connect(actionAbout, SIGNAL(triggered()), this , SLOT(about()));
+
+  connect(this->mainButton, SIGNAL(clicked()), this, SLOT(mainButtonHandler()));
 
   changeNumberOfLines(8);
   changeFontSize(30);
+  isStartStopModeActive = false;
   resetProgram();
 }
 
@@ -91,6 +99,35 @@ int MainWindow::updateTime()
   return EXIT_SUCCESS;
 }
 
+void MainWindow::mainButtonHandler()
+{
+  if(true == isStartStopModeActive)
+  {
+    if(!timer->isActive())
+    {
+      if(hitCount > 1)
+      {
+        pauseCounting();
+      }
+      else
+      {
+        mainButtonRefresh();
+      }
+    }
+    else
+    {
+      mainButtonRefresh();
+      pauseCounting();
+    }
+  }
+  else
+  {
+    mainButtonRefresh();
+  }
+
+  return;
+}
+
 void MainWindow::mainButtonRefresh()
 {
   updateTime();
@@ -225,8 +262,8 @@ void MainWindow::resetProgram()
 
 void MainWindow::pauseCounting()
 {
-  overallTime.pause();
   toggleTimer();
+  overallTime.pause();
   toggleActionPause();
 }
 
@@ -258,6 +295,7 @@ void MainWindow::mainButtonTimeoutUpdate()
 
   QString string = this->mainButton->text();
   QStringList lines = string.split("\n");
+
   if(lines.length() >= 1)
   {
     lines[0] = getHeaderLine();
@@ -266,6 +304,12 @@ void MainWindow::mainButtonTimeoutUpdate()
   {
     assert(0 && "Lines are missing");
   }
+  //update device
+#if 0
+//#ifdef Q_WS_MAEMO_5
+  osso_display_state_on();
+#endif
+  //update ui
   this->mainButton->setText(tr(lines.join("\n").toStdString().c_str()));
 
   //update stored string
@@ -470,6 +514,10 @@ void MainWindow::setupUi()
   actionPause = new QAction(this);
   actionPause->setObjectName(QString::fromUtf8("actionPause"));
 
+  actionStartStopMode = new QAction(this);
+  actionStartStopMode->setObjectName(QString::fromUtf8("actionStartStopMode"));
+  actionStartStopMode->setCheckable(true);
+
   actionShow_full_list = new QAction(this);
   actionShow_full_list->setObjectName(QString::fromUtf8("actionShow_full_list"));
 
@@ -521,6 +569,7 @@ void MainWindow::setupUi()
   menuPush_It_Menu->addAction(actionReset);
   menuPush_It_Menu->addAction(actionPause);
   menuPush_It_Menu->addAction(actionSimulated_click);
+  menuPush_It_Menu->addAction(actionStartStopMode);
   menuHelp->addAction(actionAbout);
   menuData->addAction(actionEnable_time_and_date);
   menuData->addAction(actionEnable_full_date);
@@ -543,16 +592,22 @@ void MainWindow::retranslateUi()
   actionReset->setText(QApplication::translate("MainWindow", "&Reset", 0, QApplication::UnicodeUTF8));
   actionSimulated_click->setText(QApplication::translate("MainWindow", "Push &it!", 0, QApplication::UnicodeUTF8));
   actionPause->setText(QApplication::translate("MainWindow", "&Pause", 0, QApplication::UnicodeUTF8));
+  actionStartStopMode->setText(QApplication::translate("MainWindow", "&Start+Pause Mode", 0, QApplication::UnicodeUTF8));
+
   actionShow_full_list->setText(QApplication::translate("MainWindow", "Show full &list", 0, QApplication::UnicodeUTF8));
   actionSave_full_list->setText(QApplication::translate("MainWindow", "&Save full list", 0, QApplication::UnicodeUTF8));
-  actionAbout->setText(QApplication::translate("MainWindow", "&About", 0, QApplication::UnicodeUTF8));
   actionEnable_full_date->setText(QApplication::translate("MainWindow", "Enable &full date", 0, QApplication::UnicodeUTF8));
   actionEnable_time_and_date->setText(QApplication::translate("MainWindow", "Enable &time and date", 0, QApplication::UnicodeUTF8));
+
   action_Fullscreen->setText(QApplication::translate("MainWindow", "&Fullscreen", 0, QApplication::UnicodeUTF8));
   actionResetFs->setText(QApplication::translate("MainWindow", "&Reset+Fullscreen", 0, QApplication::UnicodeUTF8));
   actionChangeNumberOfLines->setText(QApplication::translate("MainWindow", "&Lines", 0, QApplication::UnicodeUTF8));
   actionChangeFontSize->setText(QApplication::translate("MainWindow", "Font &size", 0, QApplication::UnicodeUTF8));
+
+  actionAbout->setText(QApplication::translate("MainWindow", "&About", 0, QApplication::UnicodeUTF8));
+
   mainButton->setText(QApplication::translate("MainWindow", "Start", 0, QApplication::UnicodeUTF8));
+
   menuPush_It_Menu->setTitle(QApplication::translate("MainWindow", "&Counter", 0, QApplication::UnicodeUTF8));
   menuHelp->setTitle(QApplication::translate("MainWindow", "&Help", 0, QApplication::UnicodeUTF8));
   menuData->setTitle(QApplication::translate("MainWindow", "&Data", 0, QApplication::UnicodeUTF8));
@@ -681,3 +736,16 @@ void MainWindow::resetProgramAndFullscreen()
   resetProgram();
   action_Fullscreen->trigger();
 }
+
+void MainWindow::toggleStartStopMode()
+{
+  if(true == isStartStopModeActive)
+  {
+    isStartStopModeActive = false;
+  }
+  else
+  {
+    isStartStopModeActive = true;
+  }
+  return;
+}
